# Spotlight: The OTC Commodity Research Platform

## Overview

**[Spotlight](https://spotlight.dev/)** is the world's first OTC commodity research platform. Stay on top of market
trends, discover new product opportunities, and win more sales.

The [Spotlight SDK](https://pypi.org/project/spotlight-sdk/) enables you to programmatically query dataset configurations and data.

## Installation

Set the following environment variables for your username and password for
the [Spotlight platform](https://app.spotlight.dev/).

```text
SPOTLIGHT_USER=<username>
SPOTLIGHT_PWD=<password>
```

## Support

If you need help or have feedback, please email us at [support@spotlight.dev](mailto:support@spotlight.dev).
